==> php-horde-imap-client_1.4.4.orig.tar.gz: php-horde-imap-client-1.4.4/Horde_Imap_Client-1.4.4/test/Horde/Imap/Client/SubjectParseTest.php <==
<?php
/**
 * Tests for Subject parsing.
 *
 * PHP version 5
 *
 * @category Horde
 * @package  Imap_Client
 * @author   Michael Slusarz <slusarz@horde.org>
 * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
 * @link     http://pear.horde.org/index.php?package=Imap_Client
 */

/**
 * Tests for Subject parsing.
 *
 * Copyright 2011-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 *
 * @category Horde
 * @package  Imap_Client
 * @author   Michael Slusarz <slusarz@horde.org>
 * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
 * @link     http://pear.horde.org/index.php?package=Imap_Client
 */
class Horde_Imap_Client_SubjectParseTest extends PHPUnit_Framework_TestCase
{
    public function testSubjectParse()
    {
        $imap_utils = new Horde_Imap_Client_Utils();

        $subjects = array(
            'Re: Test',
            're: Test',
            'Fwd: Test',
            'fwd: Test',
            'Fwd: Re: Test',
            'Fwd: Re: Test (fwd)',
        );

        foreach ($subjects as $val) {
            $this->assertEquals(
                'Test',
                $imap_utils->getBaseSubject($val)
            );
        }
    }

    public function testSubjectParseTabs()
    {
        $imap_utils = new Horde_Imap_Client_Utils();

        $this->assertEquals(
            "Test",
            $imap_utils->getBaseSubject("Re: re:re: fwd:[fwd: \t  Test]  (fwd)  (fwd)(fwd) ")
        );
    }

}

==> php-horde-imap-client_2.4.2.orig.tar.gz: php-horde-imap-client-2.4.2/Horde_Imap_Client-2.4.2/test/Horde/Imap/Client/SubjectParseTest.php <==
<?php
/**
 * Copyright 2011-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 *
 * @category Horde
 * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
 * @package  Imap_Client
 */

/**
 * Tests for Subject parsing.
 *
 * @author   Michael Slusarz <slusarz@horde.org>
 * @category Horde
 * @ignore
 * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
 * @package  Imap_Client
 */
class Horde_Imap_Client_SubjectParseTest extends PHPUnit_Framework_TestCase
{
    public function testSubjectParse()
    {
        $subjects = array(
            'Test',
            'Re: Test',
            're: Test',
            'Fwd: Test',
            'fwd: Test',
            'Fwd: Re: Test',
            'Fwd: Re: Test (fwd)',
            '  re    :   Test  (fwd)',
            '  re :   [foo]Test(Fwd)',
            "re \t: \tTest"
        );

        foreach ($subjects as $val) {
            $this->assertEquals(
                'Test',
                strval(new Horde_Imap_Client_Data_BaseSubject($val))
            );
        }

        // This used to throw an undefined index error.
        $this->assertEquals(
            'fwd',
            strval(new Horde_Imap_Client_Data_BaseSubject('fwd'))
        );
    }

    public function testSubjectParseTabs()
    {
        $this->assertEquals(
            "Test",
            strval(new Horde_Imap_Client_Data_BaseSubject("Re: re:re: fwd:[fwd: \t  Test]  (fwd)  (fwd)(fwd) "))
        );
    }

}
